==> e107-0.7.20.tbz: www/e107/e107_plugins/login_menu/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/login_menu/languages/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("LOGIN_MENU_L1", "Username: ");
define("LOGIN_MENU_L2", "Password: ");
define("LOGIN_MENU_L3", "Signup");
define("LOGIN_MENU_L4", "Forgot password?");
define("LOGIN_MENU_L5", "Welcome");
define("LOGIN_MENU_L6", "Remember me");
define("LOGIN_MENU_L7", "Unique user ID not recognised (possible corrupted cookie).<br />Please <a href=\"".e_BASE."index.php?logout\">click here</a> to destroy cookie.");
define("LOGIN_MENU_L8", "Logout");
define("LOGIN_MENU_L9", "Login Error");
define("LOGIN_MENU_L10", "The maintenance flag is true - this means normal visitors are being redirected to sitedown.php. To reset the flag go to admin/maintenance.");
define("LOGIN_MENU_L11", "Admin Area");
define("LOGIN_MENU_L12", "Settings");
define("LOGIN_MENU_L13", "Profile");
define("LOGIN_MENU_L14", "news item");
define("LOGIN_MENU_L15", "news items");
define("LOGIN_MENU_L16", "chatbox post");
define("LOGIN_MENU_L17", "chatbox posts");
define("LOGIN_MENU_L18", "comment");
define("LOGIN_MENU_L19", "comments");
define("LOGIN_MENU_L20", "forum post");
define("LOGIN_MENU_L21", "forum posts");
define("LOGIN_MENU_L22", "new site member");
define("LOGIN_MENU_L23", "new site members");
define("LOGIN_MENU_L24", "Click here to see list of new items");
define("LOGIN_MENU_L25", "Since your last visit there have been");
define("LOGIN_MENU_L26", "no");
define("LOGIN_MENU_L27", "and");
define("LOGIN_MENU_L28", "Login");

define("LOGIN_MENU_L29", "new article");
define("LOGIN_MENU_L30", "new articles");

// New config options
define('LOGIN_MENU_L31', 'Show New News Posts');
define('LOGIN_MENU_L32', 'Show New Article Posts');
define('LOGIN_MENU_L33', 'Show New Chatbox Posts');
define('LOGIN_MENU_L34', 'Show New Comment Posts');
define('LOGIN_MENU_L35', 'Show New Forum Posts');
define('LOGIN_MENU_L36', 'Show New Members');


define('LOGIN_MENU_L39', 'Leave Admin');
define("LOGIN_MENU_L40", "Resend Activation Email");
define("LOGIN_MENU_L41", "Login Menu Settings");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/login_menu/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/login_menu/languages/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("LOGIN_MENU_L1", "Username: ");
define("LOGIN_MENU_L2", "Password: ");
define("LOGIN_MENU_L3", "Signup");
define("LOGIN_MENU_L4", "Forgot password?");
define("LOGIN_MENU_L5", "Welcome");
define("LOGIN_MENU_L6", "Remember me");
define("LOGIN_MENU_L7", "Unique user ID not recognised (possible corrupted cookie).<br />Please <a href=\"".e_BASE."index.php?logout\">click here</a> to destroy cookie.");
define("LOGIN_MENU_L8", "Logout");
define("LOGIN_MENU_L9", "Login Error");
define("LOGIN_MENU_L10", "The maintenance flag is true - this means normal visitors are being redirected to sitedown.php. To reset the flag go to admin/maintenance.");
define("LOGIN_MENU_L11", "Admin Area");
define("LOGIN_MENU_L12", "Settings");
define("LOGIN_MENU_L13", "Profile");
define("LOGIN_MENU_L14", "news item");
define("LOGIN_MENU_L15", "news items");
define("LOGIN_MENU_L16", "chatbox post");
define("LOGIN_MENU_L17", "chatbox posts");
define("LOGIN_MENU_L18", "comment");
define("LOGIN_MENU_L19", "comments");
define("LOGIN_MENU_L20", "forum post");
define("LOGIN_MENU_L21", "forum posts");
define("LOGIN_MENU_L22", "new site member");
define("LOGIN_MENU_L23", "new site members");
define("LOGIN_MENU_L24", "Click here to see list of new items");
define("LOGIN_MENU_L25", "Since your last visit there have been");
define("LOGIN_MENU_L26", "no");
define("LOGIN_MENU_L27", "and");
define("LOGIN_MENU_L28", "Login");

define("LOGIN_MENU_L29", "new article");
define("LOGIN_MENU_L30", "new articles");

// New config options
define('LOGIN_MENU_L31', 'Show New News Posts');
define('LOGIN_MENU_L32', 'Show New Article Posts');
define('LOGIN_MENU_L33', 'Show New Chatbox Posts');
define('LOGIN_MENU_L34', 'Show New Comment Posts');
define('LOGIN_MENU_L35', 'Show New Forum Posts');
define('LOGIN_MENU_L36', 'Show New Members');


define('LOGIN_MENU_L39', 'Leave Admin');
define("LOGIN_MENU_L40", "Resend Activation Email");
define("LOGIN_MENU_L41", "Login Menu Settings");

?>
